@@ -11,18 +11,16 @@ use casper_execution_engine::{
         runtime::{self, Runtime},
         runtime_context::RuntimeContext,
     },
-    shared::{gas::Gas, newtypes::CorrelationId, wasm_prep::Preprocessor},
-    storage::{global_state::StateProvider, protocol_data::ProtocolData},
+    shared::{newtypes::CorrelationId, wasm_prep::Preprocessor},
+    storage::global_state::StateProvider,
 };
 use casper_types::{
     account::AccountHash, bytesrepr::FromBytes, system::CallStackElement, BlockTime, CLTyped,
-    DeployHash, EntryPointType, Key, Phase, ProtocolVersion, RuntimeArgs, URef, U512,
+    DeployHash, EntryPointType, Gas, Key, Phase, ProtocolVersion, RuntimeArgs, URef, U512,
 };
 
 use crate::internal::{utils, WasmTestBuilder, DEFAULT_WASM_CONFIG};
 
-use super::DEFAULT_SYSTEM_CONFIG;
-
 /// This function allows executing the contract stored in the given `wasm_file`, while capturing the
 /// output. It is essentially the same functionality as `Executor::exec`, but the return value of
 /// the contract is returned along with the effects. The purpose of this function is to test
@@ -86,21 +84,6 @@ where
         ret
     };
 
-    let protocol_data = {
-        let mint = builder.get_mint_contract_hash();
-        let handle_payment = builder.get_mint_contract_hash();
-        let standard_payment = builder.get_standard_payment_contract_hash();
-        let auction = builder.get_auction_contract_hash();
-        ProtocolData::new(
-            *DEFAULT_WASM_CONFIG,
-            *DEFAULT_SYSTEM_CONFIG,
-            mint,
-            handle_payment,
-            standard_payment,
-            auction,
-        )
-    };
-
     let transfers = Vec::default();
 
     let context = RuntimeContext::new(
@@ -122,7 +105,7 @@ where
         protocol_version,
         correlation_id,
         phase,
-        protocol_data,
+        config,
         transfers,
     );
 
@@ -135,6 +118,11 @@ where
     let wasm_config = *DEFAULT_WASM_CONFIG;
 
     let preprocessor = Preprocessor::new(wasm_config);
+
+    let system_contract_registry = context
+        .system_contract_registry()
+        .expect("must have contract registry");
+
     let parity_module = deploy_item
         .get_deploy_metadata(
             tracking_copy,
@@ -142,7 +130,7 @@ where
             correlation_id,
             &preprocessor,
             &protocol_version,
-            &protocol_data,
+            system_contract_registry,
             phase,
         )
         .expect("should get wasm module");
